<?php if(!is_single()) { global $more; $more = 0; } //enable more link ?>
<?php
/** Themify Default Variables
 *  @var object */
global $themify; ?>

<?php themify_post_before(); //hook ?>
<article id="post-<?php the_id(); ?>" <?php post_class("post clearfix " . $themify->get_categories_as_classes(get_the_id())); ?>>
	<?php themify_post_start(); //hook ?>

	<?php if($themify->hide_image != "yes"): ?>
		<?php themify_before_post_image(); // Hook ?>
		<?php
			//check if there is a video url in the custom field
			if( themify_has_post_video() ) {
				echo themify_post_video();
			} else{ ?>
			<?php
			//otherwise display the featured image
			if( $post_image = themify_get_image($themify->auto_featured_image . $themify->image_setting . "w=".$themify->width."&h=".$themify->height) ){ ?>

				<figure class="post-image <?php echo $themify->image_align; ?>">
					<?php if( 'yes' == $themify->unlink_image): ?>
						<?php echo $post_image; ?>
					<?php else: ?>
						<a href="<?php echo themify_get_featured_image_link(); ?>"><?php echo $post_image; ?><?php themify_zoom_icon(); ?></a>
					<?php endif; ?>
				</figure>

			<?php } ?>
		<?php }// end if video/image ?>
		<?php themify_after_post_image(); // Hook ?>
	<?php endif; //post image ?>

	<div class="post-content">

		<div class="post-date-wrap">
			<?php if($themify->hide_date != "yes"): ?>
				<time datetime="<?php the_time('o-m-d') ?>" class="post-date entry-date updated"><?php echo get_the_date( apply_filters( 'themify_loop_date', '' ) ) ?></time>
			<?php endif; //post date ?>
		</div>

		<?php if($themify->hide_title != "yes"): ?>
			<?php themify_before_post_title(); // Hook ?>
			<?php if($themify->unlink_title == "yes"): ?>
				<h1 class="post-title entry-title"><?php the_title(); ?></h1>
			<?php else: ?>
				<h1 class="post-title entry-title"><a href="<?php echo themify_get_featured_image_link(); ?>"><?php the_title(); ?></a></h1>
			<?php endif; //unlink post title ?>
			<?php themify_after_post_title(); // Hook ?>
		<?php endif; //post title ?>

		<?php if($themify->hide_meta != 'yes'): ?>
			<p class="post-meta entry-meta">
				<span class="post-author"><?php echo themify_get_author_link() ?></span>
				<span class="separator">/</span>
				<?php  if( !themify_get('setting-comments_posts') && comments_open() ) : ?>
						<span class="post-comment"><?php comments_popup_link( __( '0 Comments', 'themify' ), __( '1 Comment', 'themify' ), __( '% Comments', 'themify' ) ); ?> <span class="separator">/</span></span>
				<?php endif; //post comment ?>
				<?php echo ' '. get_the_term_list( get_the_id(), 'category', '<span class="post-category">', ', ', ' <span class="separator">/</span></span>' ) ?>
				<?php the_tags(' <span class="post-tag">', ', ', ' <span class="separator">/</span></span>'); ?>
			</p>
		<?php endif; //post meta ?>

		<div class="entry-content">

		<?php if ( 'excerpt' == $themify->display_content && ! is_attachment() ) : ?>

			<?php the_excerpt(); ?>

			<?php if( themify_check('setting-excerpt_more') ) : ?>
				<p><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute('echo=0'); ?>" class="more-link"><?php echo themify_check('setting-default_more_text')? themify_get('setting-default_more_text') : __('More &rarr;', 'themify') ?></a></p>
			<?php endif; ?>

		<?php elseif ( 'none' == $themify->display_content && ! is_attachment() ) : ?>

		<?php else: ?>

			<?php the_content(themify_check('setting-default_more_text')? themify_get('setting-default_more_text') : __('More &rarr;', 'themify')); ?>

		<?php endif; //display content ?>

		</div><!-- /.entry-content -->

		<?php edit_post_link(__('Edit', 'themify'), '<span class="edit-button">[', ']</span>'); ?>

	</div>
	<!-- /.post-content -->

    <?php themify_post_end(); //hook ?>
</article>
<!-- /.post -->
<?php themify_post_after(); //hook ?>
